package fishrungames.bashgid.core;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Locale;

import fishrungames.bashgid.core.AlbumManager.AlbumFullData;
import fishrungames.bashgid.core.ChannelManager.ChannelFullData;

public class ArticleManager
{
	
	public static final SimpleDateFormat iso8601Format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.US);
	
	public static final int ARTICLE_TYPE_NORMAL = 0;
	public static final int ARTICLE_TYPE_NEWS = 1;
	
	public static class ArticleRecordData
	{
		
		public String name;
		public int type;
		public String title;
		public String content;
		public double geoLat;
		public double geoLon;
		public String externalLink;
		public Date dateTime;
		
		public ArticleRecordData(String name, int type, String title, String content, double geoLat, double geoLon, String externalLink, Date dateTime)
		{
			this.name = name;
			this.type = type;
			this.title = title;
			this.content = content;
			this.geoLat = geoLat;
			this.geoLon = geoLon;
			this.externalLink = externalLink;
			this.dateTime = dateTime;
		}
		
		public ArticleRecordData(ArticleRecordData copyFrom)
		{
			this.name = copyFrom.name;
			this.type = copyFrom.type;
			this.title = copyFrom.title;
			this.content = copyFrom.content;
			this.geoLat = copyFrom.geoLat;
			this.geoLon = copyFrom.geoLon;
			this.externalLink = copyFrom.externalLink;
			this.dateTime = copyFrom.dateTime;
		}
	}
	
	public static class ArticleRecord extends ArticleRecordData
	{
		public int id;
		
		public ArticleRecord(int id, ArticleRecordData recordData)
		{
			super(recordData);
			this.id = id;
		}
	}
	
	public static class ArticleFullData extends ArticleRecordData
	{
		public ArrayList<AlbumFullData> albumArr;
		public ArrayList<ChannelFullData> channelArr;
		
		public ArticleFullData(ArticleRecordData recordData)
		{
			super(recordData);
			albumArr = new ArrayList<AlbumFullData>();
			channelArr = new ArrayList<ChannelFullData>();
		}
	}
	
	public static class ArticleShortData extends ArticleRecordData
	{
		public String previewImageUrl;
		
		public ArticleShortData(ArticleRecordData recordData)
		{
			super(recordData);
			previewImageUrl = "";
			//albumArr = new ArrayList<AlbumFullData>();
			//channelArr = new ArrayList<ChannelFullData>();
		}
	}
}
